==> flutter_local_notifications-0.1.5.tar.gz: lib/platform_specifics/android/styles/big_text_style_information.dart <==
import 'package:flutter_local_notifications/platform_specifics/android/styles/default_style_information.dart';

class BigTextStyleInformation extends DefaultStyleInformation {
  /// Provide the longer text to be displayed in the big form of the template in place of the content text.
  final String bigText;

  /// Overrides ContentTitle in the big form of the template.
  final String contentTitle;

  /// Set the first line of text after the detail section in the big form of the template.
  final String summaryText;

  /// Specifies if formatting should be applied to the longer text through HTML markup
  final bool htmlFormatBigText;

  /// Specifies if the overridden ContentTitle should have formatting applies through HTML markup
  final bool htmlFormatContentTitle;

  /// Specifies if formatting should be applied to the first line of text after the detail section in the big form of the template.
  final bool htmlFormatSummaryText;

  BigTextStyleInformation(this.bigText,
      {this.htmlFormatBigText = false,
      this.contentTitle,
      this.htmlFormatContentTitle = false,
      this.summaryText,
      this.htmlFormatSummaryText = false,
      bool htmlFormatContent = false,
      bool htmlFormatTitle = false})
      : super(htmlFormatContent, htmlFormatTitle);

  Map<String, dynamic> toJson() {
    var styleJson = super.toJson();

    var bigTextStyleJson = <String, dynamic>{
      'bigText': bigText,
      'htmlFormatBigText': htmlFormatBigText,
      'contentTitle': contentTitle,
      'htmlFormatContentTitle': htmlFormatContentTitle,
      'summaryText': summaryText,
      'htmlFormatSummaryText': htmlFormatSummaryText
    };
    styleJson.addAll(bigTextStyleJson);
    return styleJson;
  }
}

==> flutter_local_notifications-0.2.1.tar.gz: lib/platform_specifics/android/styles/big_text_style_information.dart <==
import 'package:flutter_local_notifications/platform_specifics/android/styles/default_style_information.dart';

class BigTextStyleInformation extends DefaultStyleInformation {
  /// Provide the longer text to be displayed in the big form of the template in place of the content text.
  final String bigText;

  /// Overrides ContentTitle in the big form of the template.
  final String contentTitle;

  /// Set the first line of text after the detail section in the big form of the template.
  final String summaryText;

  /// Specifies if formatting should be applied to the longer text through HTML markup
  final bool htmlFormatBigText;

  /// Specifies if the overridden ContentTitle should have formatting applies through HTML markup
  final bool htmlFormatContentTitle;

  /// Specifies if formatting should be applied to the first line of text after the detail section in the big form of the template.
  final bool htmlFormatSummaryText;

  BigTextStyleInformation(this.bigText,
      {this.htmlFormatBigText = false,
      this.contentTitle,
      this.htmlFormatContentTitle = false,
      this.summaryText,
      this.htmlFormatSummaryText = false,
      bool htmlFormatContent = false,
      bool htmlFormatTitle = false})
      : super(htmlFormatContent, htmlFormatTitle);

  Map<String, dynamic> toMap() {
    var styleJson = super.toMap();

    var bigTextStyleJson = <String, dynamic>{
      'bigText': bigText,
      'htmlFormatBigText': htmlFormatBigText,
      'contentTitle': contentTitle,
      'htmlFormatContentTitle': htmlFormatContentTitle,
      'summaryText': summaryText,
      'htmlFormatSummaryText': htmlFormatSummaryText
    };
    styleJson.addAll(bigTextStyleJson);
    return styleJson;
  }
}
